==> lxqt-panel-2.1.2.tar.xz: lxqt-panel-2.1.2/plugin-mount/translations/mount_en_GB.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_GB">
<context>
    <name>Button</name>
    <message>
        <location filename="../button.cpp" line="38"/>
        <source>Removable media/devices manager</source>
        <translation>Removable media/devices manager</translation>
    </message>
</context>
<context>
    <name>Configuration</name>
    <message>
        <location filename="../configuration.ui" line="14"/>
        <source>Removable Media Settings</source>
        <translation>Removable Media Settings</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>Behaviour</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="32"/>
        <source>When a device is connected:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="42"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Trigger the following action when eject shortcut is pressed (&lt;span style=&quot; font-weight:600;&quot;&gt;XF86Eject&lt;/span&gt; by default)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="45"/>
        <source>When eject button is pressed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="60"/>
        <source>Popup menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="61"/>
        <source>Show info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="62"/>
        <location filename="../configuration.cpp" line="64"/>
        <source>Do nothing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="65"/>
        <source>Eject All Optical Drives</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeviceActionInfo</name>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="40"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="45"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="50"/>
        <source>Removable media/devices manager</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EjectActionOptical</name>
    <message>
        <location filename="../actions/ejectaction_optical.cpp" line="59"/>
        <source>Removable media/devices manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/ejectaction_optical.cpp" line="59"/>
        <source>Ejected all optical drives</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtMountPlugin</name>
    <message>
        <location filename="../lxqtmountplugin.cpp" line="79"/>
        <source>Removable media/devices manager: Global shortcut &apos;%1&apos; cannot be registered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmountplugin.cpp" line="116"/>
        <source>Eject removable media</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuDiskItem</name>
    <message>
        <location filename="../menudiskitem.cpp" line="156"/>
        <source>Mounting of &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; failed: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="158"/>
        <location filename="../menudiskitem.cpp" line="179"/>
        <source>Removable media/devices manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="177"/>
        <source>Unmounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <location filename="../popup.cpp" line="67"/>
        <source>No devices are available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.1.3.tar.xz: lxqt-panel-2.1.3/plugin-mount/translations/mount_en_GB.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_GB">
<context>
    <name>Button</name>
    <message>
        <location filename="../button.cpp" line="38"/>
        <source>Removable media/devices manager</source>
        <translation>Removable media/devices manager</translation>
    </message>
</context>
<context>
    <name>Configuration</name>
    <message>
        <location filename="../configuration.ui" line="14"/>
        <source>Removable Media Settings</source>
        <translation>Removable Media Settings</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>Behaviour</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="32"/>
        <source>When a device is connected:</source>
        <translation>When a device is connected:</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="42"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Trigger the following action when eject shortcut is pressed (&lt;span style=&quot; font-weight:600;&quot;&gt;XF86Eject&lt;/span&gt; by default)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="45"/>
        <source>When eject button is pressed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="60"/>
        <source>Popup menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="61"/>
        <source>Show info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="62"/>
        <location filename="../configuration.cpp" line="64"/>
        <source>Do nothing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="65"/>
        <source>Eject All Optical Drives</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeviceActionInfo</name>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="40"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="45"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="50"/>
        <source>Removable media/devices manager</source>
        <translation type="unfinished">Removable media/devices manager</translation>
    </message>
</context>
<context>
    <name>EjectActionOptical</name>
    <message>
        <location filename="../actions/ejectaction_optical.cpp" line="59"/>
        <source>Removable media/devices manager</source>
        <translation type="unfinished">Removable media/devices manager</translation>
    </message>
    <message>
        <location filename="../actions/ejectaction_optical.cpp" line="59"/>
        <source>Ejected all optical drives</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtMountPlugin</name>
    <message>
        <location filename="../lxqtmountplugin.cpp" line="79"/>
        <source>Removable media/devices manager: Global shortcut &apos;%1&apos; cannot be registered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtmountplugin.cpp" line="116"/>
        <source>Eject removable media</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuDiskItem</name>
    <message>
        <location filename="../menudiskitem.cpp" line="156"/>
        <source>Mounting of &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; failed: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="158"/>
        <location filename="../menudiskitem.cpp" line="179"/>
        <source>Removable media/devices manager</source>
        <translation type="unfinished">Removable media/devices manager</translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="177"/>
        <source>Unmounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <location filename="../popup.cpp" line="67"/>
        <source>No devices are available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
